You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@lucene.apache.org by rm...@apache.org on 2020/06/16 10:26:12 UTC

[lucene-solr] branch master updated: LUCENE-9403: tune BufferedChecksum.DEFAULT_BUFFERSIZE

This is an automated email from the ASF dual-hosted git repository.

rmuir pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/lucene-solr.git


The following commit(s) were added to refs/heads/master by this push:
     new 4decd5a  LUCENE-9403: tune BufferedChecksum.DEFAULT_BUFFERSIZE
4decd5a is described below

commit 4decd5aa9c59c1a64ce43a3182784595636b1273
Author: Robert Muir <rm...@apache.org>
AuthorDate: Tue Jun 16 06:24:46 2020 -0400

    LUCENE-9403: tune BufferedChecksum.DEFAULT_BUFFERSIZE
    
    Increase the buffersize used for ChecksumIndexInput for better crc performance.
---
 lucene/core/src/java/org/apache/lucene/store/BufferedChecksum.java | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/lucene/core/src/java/org/apache/lucene/store/BufferedChecksum.java b/lucene/core/src/java/org/apache/lucene/store/BufferedChecksum.java
index 4378c9a..74b97d2 100644
--- a/lucene/core/src/java/org/apache/lucene/store/BufferedChecksum.java
+++ b/lucene/core/src/java/org/apache/lucene/store/BufferedChecksum.java
@@ -27,8 +27,8 @@ public class BufferedChecksum implements Checksum {
   private final Checksum in;
   private final byte buffer[];
   private int upto;
-  /** Default buffer size: 256 */
-  public static final int DEFAULT_BUFFERSIZE = 256;
+  /** Default buffer size: 1024 */
+  public static final int DEFAULT_BUFFERSIZE = 1024;
   
   /** Create a new BufferedChecksum with {@link #DEFAULT_BUFFERSIZE} */
   public BufferedChecksum(Checksum in) {